@@ -1,6 +1,5 @@
 simOcc <- function(J.x, J.y, n.rep, n.rep.max, beta, alpha, psi.RE = list(), p.RE = list(), 
-		   sp = FALSE, svc.cols = 1, cov.model, sigma.sq, phi, nu, 
-                   x.positive = FALSE, ...) {
+		   sp = FALSE, svc.cols = 1, cov.model, sigma.sq, phi, nu, x.positive = FALSE, ...) {
 
   # Check for unused arguments ------------------------------------------
   formal.args <- names(formals(sys.function(sys.parent())))
@@ -10,6 +9,14 @@ simOcc <- function(J.x, J.y, n.rep, n.rep.max, beta, alpha, psi.RE = list(), p.R
           warning("'",i, "' is not an argument")
   }
 
+  # Subroutines -----------------------------------------------------------
+  rmvn <- function(n, mu=0, V = matrix(1)){
+    p <- length(mu)
+    if(any(is.na(match(dim(V),p)))){stop("Dimension problem!")}
+    D <- chol(V)
+    t(matrix(rnorm(n*p), ncol=p)%*%D + rep(mu,rep(n,p)))
+  }
+
   # Check function inputs -------------------------------------------------
   # J.x -------------------------------
   if (missing(J.x)) {
@@ -168,10 +175,11 @@ simOcc <- function(J.x, J.y, n.rep, n.rep.max, beta, alpha, psi.RE = list(), p.R
       theta <- as.matrix(phi)
     }
     for (i in 1:p.svc) {
-      Sigma <- mkSpCov(coords, as.matrix(sigma.sq[i]), as.matrix(0), theta[i, ], cov.model)
+      Sigma.full <- mkSpCov(coords, as.matrix(sigma.sq[i]), as.matrix(0), theta[i, ], cov.model)
       # Random spatial process
-      w.mat[, i] <- mvrnorm(1, rep(0, J), Sigma)
+      w.mat[, i] <- rmvn(1, rep(0, J), Sigma.full)
     }
+    w.tmp <- NA
     X.w <- X[, svc.cols, drop = FALSE]
     # Convert w to a J*ptilde x 1 vector, sorted so that the p.svc values for 
     # each site are given, then the next site, then the next, etc.
@@ -182,12 +190,14 @@ simOcc <- function(J.x, J.y, n.rep, n.rep.max, beta, alpha, psi.RE = list(), p.R
     for (j in 1:J) {
       X.tilde[j, ((j - 1) * p.svc + 1):(j * p.svc)] <- X.w[j, ]
     }
+    lambda <- NA
   } else {
     w.mat <- NA
     X.w <- NA
+    lambda <- NA
+    w.tmp <- NA
   }
 
-
   # Random effects --------------------------------------------------------
   if (length(psi.RE) > 0) {
     p.occ.re <- length(unlist(psi.RE$beta.indx))
@@ -296,8 +306,9 @@ simOcc <- function(J.x, J.y, n.rep, n.rep.max, beta, alpha, psi.RE = list(), p.R
 
   return(
     list(X = X, X.p = X.p, coords = coords,
-         w = w.mat, psi = psi, z = z, p = p, y = y, 
+         w = w.mat, w.factor = w.tmp, psi = psi, z = z, p = p, y = y, 
 	 X.p.re = X.p.re, X.re = X.re, X.w = X.w, 
-	 alpha.star = alpha.star, beta.star = beta.star)
+	 alpha.star = alpha.star, beta.star = beta.star, 
+         lambda = lambda)
   )
 }
