@@ -826,11 +826,11 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
       }
       storage.mode(curr.chain) <- "integer"
       out.tmp[[i]] <- .Call("tPGOcc", y, X, X.p, X.re, X.p.re, 
-                            consts, K, n.occ.re.long, n.det.re.long,
+                            consts, n.occ.re.long, n.det.re.long,
                             beta.inits, alpha.inits, sigma.sq.psi.inits, 
                             sigma.sq.p.inits, beta.star.inits, alpha.star.inits, 
                             z.inits, z.long.indx, z.year.indx,
-                            z.dat.indx, z.long.site.indx, 
+                            z.dat.indx, 
                             beta.star.indx, beta.level.indx,
                             alpha.star.indx, alpha.level.indx,
                             mu.beta, Sigma.beta, mu.alpha, Sigma.alpha, 
@@ -1089,11 +1089,11 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
       storage.mode(beta.star.indx.fit) <- "integer"
 
       out.fit <- .Call("tPGOcc", y.fit, X.fit, X.p.fit, X.re.fit, X.p.re.fit, 
-                       consts.fit, K.fit, n.occ.re.long.fit, n.det.re.long.fit,
+                       consts.fit, n.occ.re.long.fit, n.det.re.long.fit,
                        beta.inits, alpha.inits, sigma.sq.psi.inits, 
                        sigma.sq.p.inits, beta.star.inits.fit, alpha.star.inits.fit, 
                        z.inits.fit, z.long.indx.fit, z.year.indx.fit,
-                       z.dat.indx.fit, z.long.site.indx.fit, 
+                       z.dat.indx.fit,
                        beta.star.indx.fit, beta.level.indx.fit,
                        alpha.star.indx.fit, alpha.level.indx.fit,
                        mu.beta, Sigma.beta, mu.alpha, Sigma.alpha, 
