@@ -25,15 +25,20 @@ static const R_CallMethodDef CallEntries[] = {
     {"sfJSDMNNGP", (DL_FUNC) &sfJSDMNNGP, 44},
     {"tPGOcc", (DL_FUNC) &tPGOcc, 44},
     {"stPGOccNNGP", (DL_FUNC) &stPGOccNNGP, 64},
-    {"stPGOccNNGPPredict", (DL_FUNC) &stPGOccNNGPPredict, 19},
+    {"stPGOccNNGPPredict", (DL_FUNC) &stPGOccNNGPPredict, 21},
     {"svcPGBinomNNGP", (DL_FUNC) &svcPGBinomNNGP, 45},
     {"svcPGOccNNGPPredict", (DL_FUNC) &svcPGOccNNGPPredict, 20},
-    {"svcPGOccNNGP", (DL_FUNC) &svcPGOccNNGP, 59},
+    {"svcPGOccNNGP", (DL_FUNC) &svcPGOccNNGP, 63},
     {"svcTPGBinomNNGP", (DL_FUNC) &svcTPGBinomNNGP, 51},
-    {"svcTPGOccNNGPPredict", (DL_FUNC) &svcTPGOccNNGPPredict, 22},
+    {"svcTPGOccNNGPPredict", (DL_FUNC) &svcTPGOccNNGPPredict, 24},
     {"svcTPGOccNNGP", (DL_FUNC) &svcTPGOccNNGP, 65},
     {"intMsPGOcc", (DL_FUNC) &intMsPGOcc, 46},
     {"postHocLM", (DL_FUNC) &postHocLM, 21},
+    {"svcMsPGOccNNGP", (DL_FUNC) &svcMsPGOccNNGP, 64},
+    {"svcMsPGOccNNGPPredict", (DL_FUNC) &svcMsPGOccNNGPPredict, 22},
+    {"svcTMsPGOccNNGP", (DL_FUNC) &svcTMsPGOccNNGP, 61},
+    {"svcTMsPGOccNNGPPredict", (DL_FUNC) &svcTMsPGOccNNGPPredict, 26},
+    {"stMsPGOccNNGP", (DL_FUNC) &svcTMsPGOccNNGP, 58},
     {NULL, NULL, 0}
 };
 
