@@ -303,9 +303,10 @@ extern "C" {
 		          SEXP pOcc_r, SEXP m_r, SEXP X0_r, SEXP coords0_r, 
 			  SEXP q_r, SEXP nnIndx0_r, SEXP betaSamples_r, 
 			  SEXP thetaSamples_r, SEXP wSamples_r, 
-			  SEXP betaStarSiteSamples_r, SEXP etaSamples_r, SEXP nSamples_r, 
-			  SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
-			  SEXP nReport_r);
+			  SEXP betaStarSiteSamples_r, SEXP etaSamples_r, 
+                          SEXP sitesLink_r, SEXP sites0Sampled_r, 
+			  SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, 
+			  SEXP verbose_r, SEXP nReport_r);
 
   SEXP svcPGBinomNNGP(SEXP y_r, SEXP X_r, SEXP Xw_r, SEXP coords_r, SEXP XRE_r, 
 	            SEXP consts_r, SEXP weights_r, SEXP nRELong_r, SEXP m_r, SEXP nnIndx_r, 
@@ -339,17 +340,17 @@ extern "C" {
 		    SEXP betaStarting_r, SEXP alphaStarting_r, SEXP sigmaSqPsiStarting_r,
 		    SEXP sigmaSqPStarting_r, SEXP betaStarStarting_r, SEXP alphaStarStarting_r, 
 	            SEXP zStarting_r, SEXP wStarting_r, SEXP phiStarting_r, 
-	            SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
+	            SEXP sigmaSqStarting_r, SEXP lambdaStarting_r, SEXP nuStarting_r, 
 	            SEXP zLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
 		    SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
 	            SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
-	            SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
+	            SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP lambdaDiagA_r, SEXP lambdaDiagB_r,
+		    SEXP muLambda_r, SEXP sigmaLambda_r, SEXP nuA_r, SEXP nuB_r, 
 		    SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
 		    SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
-	            SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
+	            SEXP tuning_r, SEXP lambdaTuning_r, SEXP covModel_r, SEXP nBatch_r, 
 	            SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
-	            SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r, 
-		    SEXP fixedParams_r, SEXP sigmaSqIG_r);
+	            SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r);
 
   SEXP svcTPGBinomNNGP(SEXP y_r, SEXP X_r, SEXP Xw_r, SEXP coords_r, SEXP XRE_r, 
 		       SEXP consts_r, SEXP weights_r, SEXP nRELong_r, 
@@ -373,9 +374,10 @@ extern "C" {
 			    SEXP coords0_r, SEXP weights0_r, 
 			    SEXP q_r, SEXP nnIndx0_r, SEXP betaSamples_r, 
 			    SEXP thetaSamples_r, SEXP wSamples_r, 
-			    SEXP betaStarSiteSamples_r, SEXP etaSamples_r, SEXP nSamples_r, 
-			    SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
-			    SEXP nReport_r);
+			    SEXP betaStarSiteSamples_r, SEXP etaSamples_r, 
+                            SEXP sitesLink_r, SEXP sites0Sampled_r, 
+			    SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, 
+			    SEXP verbose_r, SEXP nReport_r);
 
   SEXP svcTPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xw_r, SEXP Xp_r, SEXP coords_r, SEXP XRE_r, 
 		     SEXP XpRE_r, SEXP consts_r, 
@@ -430,4 +432,90 @@ extern "C" {
                  SEXP verbose_r, SEXP nReport_r, 
 	         SEXP chainInfo_r);
 
+  SEXP svcMsPGOccNNGPPredict(SEXP coords_r, SEXP J_r, SEXP N_r, SEXP q_r,
+		             SEXP pOcc_r, SEXP pTilde_r, SEXP m_r, 
+			     SEXP X0_r, SEXP Xw0_r, SEXP coords0_r, 
+			     SEXP JStr_r, SEXP nnIndx0_r, SEXP betaSamples_r, 
+			     SEXP thetaSamples_r, SEXP lambdaSamples_r, 
+			     SEXP wSamples_r, SEXP betaStarSiteSamples_r, 
+			     SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
+			     SEXP nReport_r);
+
+  SEXP svcMsPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xw_r, SEXP Xp_r, SEXP coords_r, SEXP XRE_r, SEXP XpRE_r, 
+		      SEXP rangeInd_r, SEXP consts_r, SEXP K_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
+		      SEXP m_r, SEXP nnIndx_r, 
+		      SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r, 
+		      SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
+		      SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
+		      SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
+		      SEXP phiStarting_r, SEXP lambdaStarting_r, SEXP wStarting_r, 
+		      SEXP nuStarting_r, 
+		      SEXP sigmaSqPsiStarting_r, SEXP sigmaSqPStarting_r, 
+		      SEXP betaStarStarting_r, SEXP alphaStarStarting_r, SEXP zLongIndx_r,
+		      SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
+		      SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r,
+		      SEXP muBetaComm_r, SEXP muAlphaComm_r, 
+	              SEXP SigmaBetaComm_r, SEXP SigmaAlphaComm_r, SEXP tauSqBetaA_r, 
+	              SEXP tauSqBetaB_r, SEXP tauSqAlphaA_r, SEXP tauSqAlphaB_r, SEXP phiA_r, 
+		      SEXP phiB_r, SEXP nuA_r, SEXP nuB_r, 
+		      SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
+		      SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
+		      SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
+		      SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
+		      SEXP samplesInfo_r, SEXP chainInfo_r);
+
+  SEXP svcTMsPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xw_r, SEXP Xp_r, 
+		      SEXP coords_r, SEXP XRE_r, SEXP XpRE_r, SEXP rangeInd_r,
+		      SEXP consts_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
+		      SEXP m_r, SEXP nnIndx_r, 
+		      SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r, 
+		      SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
+		      SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
+		      SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
+		      SEXP phiStarting_r, SEXP lambdaStarting_r, SEXP nuStarting_r, 
+		      SEXP sigmaSqPsiStarting_r, SEXP sigmaSqPStarting_r, 
+		      SEXP betaStarStarting_r, SEXP alphaStarStarting_r, SEXP zLongIndx_r,
+		      SEXP zYearIndx_r, SEXP zDatIndx_r, SEXP zSiteIndx_r,
+		      SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
+		      SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r,
+		      SEXP betaCommPriors_r, SEXP alphaCommPriors_r, 
+	              SEXP tauSqBetaPriors_r, SEXP tauSqAlphaPriors_r, SEXP phiPriors_r, 
+		      SEXP nuPriors_r, SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
+		      SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
+		      SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
+		      SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
+		      SEXP samplesInfo_r, SEXP chainInfo_r, SEXP ar1Vals_r, SEXP svcBySp_r);
+
+  SEXP svcTMsPGOccNNGPPredict(SEXP coords_r, SEXP J_r, SEXP nYearsMax_r, SEXP N_r, SEXP q_r,
+		              SEXP pOcc_r, SEXP pTilde_r, SEXP m_r, 
+			      SEXP X0_r, SEXP Xw0_r, SEXP coords0_r, 
+			      SEXP JStr_r, SEXP nnIndx0_r, SEXP betaSamples_r, 
+			      SEXP thetaSamples_r, SEXP lambdaSamples_r, 
+			      SEXP wSamples_r, SEXP betaStarSiteSamples_r, SEXP etaSamples_r, 
+			      SEXP sitesLink_r, SEXP sites0Sampled_r,
+			      SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
+			      SEXP nReport_r);
+
+  SEXP stMsPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xp_r, 
+		      SEXP coords_r, SEXP XRE_r, SEXP XpRE_r, 
+		      SEXP consts_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
+		      SEXP m_r, SEXP nnIndx_r, 
+		      SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r, 
+		      SEXP betaStarting_r, SEXP alphaStarting_r, SEXP zStarting_r, 
+		      SEXP betaCommStarting_r, SEXP alphaCommStarting_r, 
+		      SEXP tauSqBetaStarting_r, SEXP tauSqAlphaStarting_r, 
+		      SEXP phiStarting_r, SEXP lambdaStarting_r, SEXP nuStarting_r, 
+		      SEXP sigmaSqPsiStarting_r, SEXP sigmaSqPStarting_r, 
+		      SEXP betaStarStarting_r, SEXP alphaStarStarting_r, SEXP zLongIndx_r,
+		      SEXP zYearIndx_r, SEXP zDatIndx_r, SEXP zSiteIndx_r,
+		      SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
+		      SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r,
+		      SEXP betaCommPriors_r, SEXP alphaCommPriors_r, 
+	              SEXP tauSqBetaPriors_r, SEXP tauSqAlphaPriors_r, SEXP phiPriors_r, 
+		      SEXP nuPriors_r, SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
+		      SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
+		      SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, SEXP batchLength_r, 
+		      SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, SEXP nReport_r, 
+		      SEXP samplesInfo_r, SEXP chainInfo_r, SEXP ar1Vals_r);
+
 }
